@@ -1,16 +1,15 @@
 #
 # This file is part of Test-Apocalypse
 #
-# This software is copyright (c) 2011 by Apocalypse.
+# This software is copyright (c) 2014 by Apocalypse.
 #
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
 #
 use strict; use warnings;
 package Test::Apocalypse;
-BEGIN {
-  $Test::Apocalypse::VERSION = '1.002';
-}
+# git description: release-1.002-29-g47fa54f
+$Test::Apocalypse::VERSION = '1.003';
 BEGIN {
   $Test::Apocalypse::AUTHORITY = 'cpan:APOCAL';
 }
@@ -18,9 +17,7 @@ BEGIN {
 # ABSTRACT: Apocalypse's favorite tests bundled into a simple interface
 
 # setup our tests and etc
-use Test::Block 0.11 qw( $Plan );
 use Test::More 0.96;
-use Test::Builder 0.96;
 use Module::Pluggable 3.9 search_path => [ __PACKAGE__ ];
 
 # auto-export the only sub we have
@@ -32,22 +29,18 @@ sub is_apocalypse_here {
 	unless ( $ENV{RELEASE_TESTING} or $ENV{AUTOMATED_TESTING} ) {
 		plan skip_all => 'Author test. Please set $ENV{RELEASE_TESTING} to a true value to run.';
 	} else {
-		plan 'no_plan';
-
-		# load our nifty "catch-all" tests
-		# TODO should this be required?
-		eval "use Test::NoWarnings";
+		require Test::FailWarnings;
 	}
 
 	# The options hash
 	my %opt;
 
 	# Support passing in a hash ref or a regular hash
-	if ( ( @_ & 1 ) and ref $_[0] and ref( $_[0] ) eq 'HASH' ) {
+	if ( ( @_ & 1 ) and ref $_[0] and ref( $_[0] ) eq 'HASH' ) { ## no critic (Bangs::ProhibitBitwiseOperators)
 		%opt = %{ $_[0] };
 	} else {
 		# Sanity checking
-		if ( @_ & 1 ) {
+		if ( @_ & 1 ) { ## no critic (Bangs::ProhibitBitwiseOperators)
 			die 'The sub is_apocalypse_here() requires an even number of options';
 		}
 
@@ -126,80 +119,74 @@ sub is_apocalypse_here {
 		}
 
 		# Is this plugin disabled?
-		if ( $t->can( '_is_disabled' ) and $t->_is_disabled ) {
+		if ( $t->can( '_is_disabled' ) and $t->_is_disabled and ! $ENV{PERL_APOCALYPSE} ) {
 			diag( "Skipping $plugin ( plugin is DISABLED )..." );
 			next;
 		}
 
 		# Check for AUTOMATED_TESTING
 		if ( $ENV{AUTOMATED_TESTING} and ! $ENV{PERL_APOCALYPSE} and $t->can( '_do_automated' ) and ! $t->_do_automated() ) {
-			diag( "Skipping $t ( for RELEASE_TESTING only )..." );
+			diag( "Skipping $plugin ( for RELEASE_TESTING only )..." );
 			next;
 		}
 
-		# do nasty override of Test::Builder::plan
-		local $Plan;
-		my $newplan = sub {
-			my( $self, $cmd, $arg ) = @_;
-			return unless $cmd;
-
-			# handle the cmds
-			if ( $cmd eq 'skip_all' ) {
-				$Plan = { $plugin => 1 };
-				SKIP: {
-					$self->skip( "$plugin - $arg", 1 );
-				}
-			} elsif ( $cmd eq 'tests' ) {
-				$Plan = { $plugin => $arg };
-			} elsif ( $cmd eq 'no_plan' ) {
-				# ignore it
-				$Plan = { $plugin => 0 };
-			} else {
-				die "Unknown cmd: $cmd";
-			}
-
-			return 1;
-		};
-
-		# Same thing for Test::Builder::create - Test::NoPlan uses it, argh!
-		my $newcreate = sub {
-			diag( "ARGH! $plugin uses Test::Builder::create() - go patch it!" );
-			goto &Test::Builder::new;
-		};
-
-		no warnings 'redefine'; no strict 'refs';
-		local *{'Test::Builder::plan'} = $newplan;
-		local *{'Test::Builder::create'} = $newcreate;
-
 		# run it!
-		use warnings; use strict;
-		diag( "Running $plugin..." );
-		$t->do_test();
+		diag( "Executing $plugin..." );
+		subtest $plugin => sub {
+			eval {
+				# TODO ignore annoying gpg warnings like 'WARNING: This key is not certified with a trusted signature!' at /usr/local/share/perl/5.18.2/Module/Signature.pm line 265.
+				no warnings qw(once);
+				local @Test::FailWarnings::ALLOW_FROM = ( 'Module::Signature' );
 
-#		# TODO oh, I wish it was this easy...
-#		subtest $t => sub {
-#			$t->do_test();
-#		};
-#		ok( 1, "done with $t" );
+				local $SIG{__WARN__} = \&Test::FailWarnings::handler;
+				$t->do_test();
+			};
+			if ( $@ ) {
+				# Sometimes we get a plain string, sometimes we get
+				# Error running Kwalitee: Test::Builder::Exception=HASH(0x3fa6078)
+				my $err = $@;
+				if ( $err->isa( 'Test::Builder::Exception' ) ) {
+					# TODO reach into T::B to get the actual skip reason
+					$err = Test::Builder->new->{Skip_All};
+				}
+
+				if ( $ENV{RELEASE_TESTING} or $ENV{PERL_APOCALYPSE} ) {
+					die "Error running $plugin: $err";
+				} else {
+					diag( "Error running $plugin: $err" );
+				}
+
+				# we need to manually intervene or we'll get this:
+				# Running DOSnewline...
+				# Running Dependencies...
+					# Child (Dependencies) exited without calling finalize()
+					#   Failed test 'Dependencies'
+					#   at /usr/local/share/perl/5.18.2/Test/Apocalypse.pm line 134.
+					# Error running Dependencies: Can't locate object method "new" via package "Version::Requirements" (perhaps you forgot to load "Version::Requirements"?) at /usr/local/share/perl/5.18.2/Test/Apocalypse/Dependencies.pm line 59.
+				# Running DirChecks...
+				# Error running DirChecks: You already have a child named (Dependencies) running at /usr/local/share/perl/5.18.2/Test/More.pm line 771.
+				done_testing();
+			}
+		};
 	}
 
-	# done with testing
+	done_testing();
 	return 1;
 }
 
 1;
 
-
 __END__
+
 =pod
 
-=for :stopwords Apocalypse cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee
-diff irc mailto metadata placeholders apocal CPAN AUTHORs al backend debian
-distro distros dists env hackish plugins testsuite yml pm yay unicode blog
-precompiled =for stopwords ap cyclomatic cal dist homebrew imo internet
-perltidy prefs prereq testrun
+=encoding UTF-8
 
-=encoding utf-8
+=for :stopwords Apocalypse Niebur Ryan cpan testmatrix url annocpan anno bugtracker rt
+cpants kwalitee diff irc mailto metadata placeholders metacpan apocal CPAN
+AUTHORs al backend debian distro distros dists env hackish plugins
+testsuite yml pm yay unicode blog precompiled =for stopwords ap cyclomatic
+cal dist homebrew imo internet perltidy prefs prereq testrun
 
 =head1 NAME
 
@@ -207,7 +194,7 @@ Test::Apocalypse - Apocalypse's favorite tests bundled into a simple interface
 
 =head1 VERSION
 
-  This document describes v1.002 of Test::Apocalypse - released April 21, 2011 as part of Test-Apocalypse.
+  This document describes v1.003 of Test::Apocalypse - released October 24, 2014 as part of Test-Apocalypse.
 
 =head1 SYNOPSIS
 
@@ -231,7 +218,7 @@ updated!
 
 This module respects the RELEASE_TESTING/AUTOMATED_TESTING env variable, if it is not set it will skip the entire
 testsuite. Normally end-users should not run it; but you can if you want to see how bad my dists are, ha! The scheme
-is exactly the same as the one Alias proposed in L<Test::XT> and in his blog post, L<http://use.perl.org/~Alias/journal/38822>.
+is exactly the same as the one Alias proposed in L<Test::XT> and in his blog post, L<http://use.perl.org/use.perl.org/_Alias/journal/38822.html>.
 
 This module uses L<Module::Pluggable> to have custom "backends" that process various tests. We wrap them in a hackish
 L<Test::Block> block per-plugin and it seems to work nicely. If you want to write your own, it should be a breeze
@@ -309,11 +296,6 @@ I don't use Smart::Comments but it might be useful? I LOVE BLOAT! :)
 
 Test::Spelling is ancient, and often blows up. There's a Test::Pod::Spelling on CPAN but it is flaky too :(
 
-=item * CPAN RT check?
-
-I want a test that checks the CPAN RT for any tickets, and display it when running the test. That would be helpful to remind me to be punctual
-with my tickets, ha!
-
 =item * Document the way we do plugins so others can add to this testsuite :)
 
 =item * POD standards check
@@ -375,10 +357,6 @@ It would be nice to signal INTERNET_TESTING=0 or something zany like that so thi
 	<@Alias> Setting a proxy ENVthat is illegal etc
 	<Apocalypse> ah good thinking, I'll read up on the fine points of LWP env vars and try to screw it up
 
-=item * Test::CPAN::Changes
-
-Use the newfangled CPAN Changes spec :)
-
 =back
 
 =head2 Modules that I considered but decided against using
@@ -471,6 +449,14 @@ in addition to those websites please use your favorite search engine to discover
 
 =item *
 
+MetaCPAN
+
+A modern, open-source CPAN search engine, useful to view POD in HTML format.
+
+L<http://metacpan.org/release/Test-Apocalypse>
+
+=item *
+
 Search CPAN
 
 The default CPAN search engine, useful to view POD in HTML format.
@@ -489,7 +475,7 @@ L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Test-Apocalypse>
 
 AnnoCPAN
 
-The AnnoCPAN is a website that allows community annonations of Perl module documentation.
+The AnnoCPAN is a website that allows community annotations of Perl module documentation.
 
 L<http://annocpan.org/dist/Test-Apocalypse>
 
@@ -529,7 +515,7 @@ L<http://www.cpantesters.org/distro/T/Test-Apocalypse>
 
 CPAN Testers Matrix
 
-The CPAN Testers Matrix is a website that provides a visual way to determine what Perls/platforms PASSed for a distribution.
+The CPAN Testers Matrix is a website that provides a visual overview of the test results for a distribution on various Perls/platforms.
 
 L<http://matrix.cpantesters.org/?dist=Test-Apocalypse>
 
@@ -588,7 +574,7 @@ The code is open to the world, and available for you to hack on. Please feel fre
 with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
 from your repository :)
 
-L<http://github.com/apocalypse/perl-test-apocalypse>
+L<https://github.com/apocalypse/perl-test-apocalypse>
 
   git clone git://github.com/apocalypse/perl-test-apocalypse.git
 
@@ -596,41 +582,63 @@ L<http://github.com/apocalypse/perl-test-apocalypse>
 
 Apocalypse <APOCAL@cpan.org>
 
+=head2 CONTRIBUTORS
+
+=for stopwords Apocalypse Ryan Niebur
+
+=over 4
+
+=item *
+
+Apocalypse <apoc@blackhole.(none)>
+
+=item *
+
+Apocalypse <apoc@satellite.(none)>
+
+=item *
+
+Apocalypse <perl@0ne.us>
+
+=item *
+
+Ryan Niebur <ryanryan52@gmail.com>
+
+=back
+
 =head1 ACKNOWLEDGEMENTS
 
 Thanks to jawnsy@cpan.org for the prodding and help in getting this package ready to be bundled into debian!
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Apocalypse.
+This software is copyright (c) 2014 by Apocalypse.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
-The full text of the license can be found in the LICENSE file included with this distribution.
+The full text of the license can be found in the
+F<LICENSE> file included with this distribution.
 
 =head1 DISCLAIMER OF WARRANTY
 
-BECAUSE THIS SOFTWARE IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY
-FOR THE SOFTWARE, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT
-WHEN OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER
-PARTIES PROVIDE THE SOFTWARE "AS IS" WITHOUT WARRANTY OF ANY KIND,
-EITHER EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE
-IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
-PURPOSE. THE ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE
-SOFTWARE IS WITH YOU. SHOULD THE SOFTWARE PROVE DEFECTIVE, YOU ASSUME
-THE COST OF ALL NECESSARY SERVICING, REPAIR, OR CORRECTION.
+THERE IS NO WARRANTY FOR THE PROGRAM, TO THE EXTENT PERMITTED BY
+APPLICABLE LAW.  EXCEPT WHEN OTHERWISE STATED IN WRITING THE COPYRIGHT
+HOLDERS AND/OR OTHER PARTIES PROVIDE THE PROGRAM "AS IS" WITHOUT WARRANTY
+OF ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO,
+THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
+PURPOSE.  THE ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE PROGRAM
+IS WITH YOU.  SHOULD THE PROGRAM PROVE DEFECTIVE, YOU ASSUME THE COST OF
+ALL NECESSARY SERVICING, REPAIR OR CORRECTION.
 
 IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING
-WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR
-REDISTRIBUTE THE SOFTWARE AS PERMITTED BY THE ABOVE LICENCE, BE LIABLE
-TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL, OR
-CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE THE
-SOFTWARE (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING
-RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A
-FAILURE OF THE SOFTWARE TO OPERATE WITH ANY OTHER SOFTWARE), EVEN IF
-SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH
-DAMAGES.
+WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MODIFIES AND/OR CONVEYS
+THE PROGRAM AS PERMITTED ABOVE, BE LIABLE TO YOU FOR DAMAGES, INCLUDING ANY
+GENERAL, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE
+USE OR INABILITY TO USE THE PROGRAM (INCLUDING BUT NOT LIMITED TO LOSS OF
+DATA OR DATA BEING RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD
+PARTIES OR A FAILURE OF THE PROGRAM TO OPERATE WITH ANY OTHER PROGRAMS),
+EVEN IF SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF
+SUCH DAMAGES.
 
 =cut
-
