@@ -1,16 +1,14 @@
 #
 # This file is part of Test-Apocalypse
 #
-# This software is copyright (c) 2011 by Apocalypse.
+# This software is copyright (c) 2014 by Apocalypse.
 #
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
 #
 use strict; use warnings;
 package Test::Apocalypse::Dependencies;
-BEGIN {
-  $Test::Apocalypse::Dependencies::VERSION = '1.002';
-}
+$Test::Apocalypse::Dependencies::VERSION = '1.003';
 BEGIN {
   $Test::Apocalypse::Dependencies::AUTHORITY = 'cpan:APOCAL';
 }
@@ -24,6 +22,7 @@ use JSON::Any 1.25;
 use File::Find::Rule 0.32;
 use Perl::PrereqScanner 1.000;
 use Test::Deep 0.108;
+use CPAN::Meta::Requirements 2.113640;
 
 sub _do_automated { 0 }
 
@@ -47,17 +46,9 @@ sub do_test {
 		die 'No META.(json|yml) found!';
 	}
 
-	# remove 'perl' dep - we check it in MinimumVersion anyway
-	delete $runtime_req->{'perl'} if exists $runtime_req->{'perl'};
-	delete $test_req->{'perl'} if defined $test_req and exists $test_req->{'perl'};
-
-	# Convert version objects to regular
-	$runtime_req->{ $_ } =~ s/^v// for keys %$runtime_req;
-	$test_req->{ $_ } =~ s/^v// for keys %$test_req;
-
 	# Okay, scan the files
-	my $found_runtime = Version::Requirements->new;
-	my $found_test = Version::Requirements->new;
+	my $found_runtime = CPAN::Meta::Requirements->new;
+	my $found_test = CPAN::Meta::Requirements->new;
 	foreach my $file ( File::Find::Rule->file()->name( qr/\.pm$/ )->in( 'lib' ) ) {
 		$found_runtime->add_requirements( Perl::PrereqScanner->new->scan_file( $file ) );
 	}
@@ -112,28 +103,53 @@ sub do_test {
 		}
 	}
 
+	# remove 'perl' dep - we check it in MinimumVersion anyway
+	delete $runtime_req->{'perl'} if exists $runtime_req->{'perl'};
+	delete $test_req->{'perl'} if defined $test_req and exists $test_req->{'perl'};
+	$found_runtime->clear_requirement( 'perl' );
+	$found_test->clear_requirement( 'perl' );
+
+	# Convert version objects to regular or we'll get something like this:
+	# Compared $data->{"Test\:\:NoPlan"}
+	#    got : 'v0.0.6'
+	# expect : '0.0.6'
+	$found_runtime = $found_runtime->as_string_hash;
+	$found_runtime->{ $_ } =~ s/^v// for keys %$found_runtime;
+	$runtime_req->{ $_ } =~ s/^v// for keys %$runtime_req;
+
 	# Do the actual comparison!
 	if ( defined $test_req ) {
 		plan tests => 2;
+
+		$found_test = $found_test->as_string_hash;
+		$found_test->{ $_ } =~ s/^v// for keys %$found_test;
+		$test_req->{ $_ } =~ s/^v// for keys %$test_req;
+
+		# TODO interesting, somewhere deep in the build chain it auto-upgraded Test::More version...
+		# I had 0.88 set but somehow 0.96 was in the META.yml argh!
+		if ( $found_test->{'Test::More'} ne $test_req->{'Test::More'} ) {
+			diag( 'Found weird Test::More version mismatch, ignoring it! (' . $found_test->{'Test::More'} . ' vs ' . $test_req->{'Test::More'} . ')' );
+			$found_test->{'Test::More'} = $test_req->{'Test::More'};
+		}
 	} else {
 		plan tests => 1;
 	}
 
-	cmp_deeply( $found_runtime->as_string_hash, $runtime_req, "Runtime requires" );
-	cmp_deeply( $found_test->as_string_hash, $test_req, "Test requires" ) if defined $test_req;
+	cmp_deeply( $found_runtime, $runtime_req, "Runtime requires" );
+	cmp_deeply( $found_test, $test_req, "Test requires" ) if defined $test_req;
 
 	return;
 }
 
 1;
 
-
 __END__
+
 =pod
 
-=for :stopwords Apocalypse metadata
+=encoding UTF-8
 
-=encoding utf-8
+=for :stopwords Apocalypse Niebur Ryan metadata
 
 =for Pod::Coverage do_test
 
@@ -143,7 +159,7 @@ Test::Apocalypse::Dependencies - Plugin to check for metadata dependencies
 
 =head1 VERSION
 
-  This document describes v1.002 of Test::Apocalypse::Dependencies - released April 21, 2011 as part of Test-Apocalypse.
+  This document describes v1.003 of Test::Apocalypse::Dependencies - released October 24, 2014 as part of Test-Apocalypse.
 
 =head1 DESCRIPTION
 
@@ -167,35 +183,33 @@ Apocalypse <APOCAL@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Apocalypse.
+This software is copyright (c) 2014 by Apocalypse.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
-The full text of the license can be found in the LICENSE file included with this distribution.
+The full text of the license can be found in the
+F<LICENSE> file included with this distribution.
 
 =head1 DISCLAIMER OF WARRANTY
 
-BECAUSE THIS SOFTWARE IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY
-FOR THE SOFTWARE, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT
-WHEN OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER
-PARTIES PROVIDE THE SOFTWARE "AS IS" WITHOUT WARRANTY OF ANY KIND,
-EITHER EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE
-IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
-PURPOSE. THE ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE
-SOFTWARE IS WITH YOU. SHOULD THE SOFTWARE PROVE DEFECTIVE, YOU ASSUME
-THE COST OF ALL NECESSARY SERVICING, REPAIR, OR CORRECTION.
+THERE IS NO WARRANTY FOR THE PROGRAM, TO THE EXTENT PERMITTED BY
+APPLICABLE LAW.  EXCEPT WHEN OTHERWISE STATED IN WRITING THE COPYRIGHT
+HOLDERS AND/OR OTHER PARTIES PROVIDE THE PROGRAM "AS IS" WITHOUT WARRANTY
+OF ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO,
+THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
+PURPOSE.  THE ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE PROGRAM
+IS WITH YOU.  SHOULD THE PROGRAM PROVE DEFECTIVE, YOU ASSUME THE COST OF
+ALL NECESSARY SERVICING, REPAIR OR CORRECTION.
 
 IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING
-WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR
-REDISTRIBUTE THE SOFTWARE AS PERMITTED BY THE ABOVE LICENCE, BE LIABLE
-TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL, OR
-CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE THE
-SOFTWARE (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING
-RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A
-FAILURE OF THE SOFTWARE TO OPERATE WITH ANY OTHER SOFTWARE), EVEN IF
-SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH
-DAMAGES.
+WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MODIFIES AND/OR CONVEYS
+THE PROGRAM AS PERMITTED ABOVE, BE LIABLE TO YOU FOR DAMAGES, INCLUDING ANY
+GENERAL, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE
+USE OR INABILITY TO USE THE PROGRAM (INCLUDING BUT NOT LIMITED TO LOSS OF
+DATA OR DATA BEING RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD
+PARTIES OR A FAILURE OF THE PROGRAM TO OPERATE WITH ANY OTHER PROGRAMS),
+EVEN IF SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF
+SUCH DAMAGES.
 
 =cut
-
