@@ -1,16 +1,14 @@
 #
 # This file is part of Test-Apocalypse
 #
-# This software is copyright (c) 2011 by Apocalypse.
+# This software is copyright (c) 2014 by Apocalypse.
 #
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
 #
 use strict; use warnings;
 package Test::Apocalypse::Kwalitee;
-BEGIN {
-  $Test::Apocalypse::Kwalitee::VERSION = '1.002';
-}
+$Test::Apocalypse::Kwalitee::VERSION = '1.003';
 BEGIN {
   $Test::Apocalypse::Kwalitee::AUTHORITY = 'cpan:APOCAL';
 }
@@ -18,7 +16,7 @@ BEGIN {
 # ABSTRACT: Plugin for Test::Kwalitee
 
 use Test::More;
-use Module::CPANTS::Analyse 0.85;
+use Module::CPANTS::Analyse 0.95;
 use version 0.77;
 
 sub _do_automated { 0 }
@@ -53,7 +51,7 @@ sub _analyze {
 
 	# set the number of tests / run analyzer
 	my @indicators = $analyzer->mck()->get_indicators();
-	plan tests => scalar @indicators - 3;	# remove the problematic tests
+	plan tests => scalar @indicators;
 	$analyzer->unpack;
 	$analyzer->analyse;
 	$analyzer->calc_kwalitee;
@@ -63,10 +61,6 @@ sub _analyze {
 	# loop over the kwalitee metrics
 	foreach my $gen ( @{ $analyzer->mck()->generators() } ) {
 		foreach my $metric ( @{ $gen->kwalitee_indicators() } ) {
-			# skip problematic ones
-			if ( $metric->{'name'} =~ /^(?:is_prereq|prereq_matches_use|build_prereq_matches_use)$/ ) { next }
-			#if ( $metric->{'name'} =~ /^(?:is_prereq)$/ ) { next }
-
 			# get the result
 			my $result = $metric->{'code'}->( $analyzer->d(), $metric );
 			my $type = 'CORE';
@@ -77,18 +71,22 @@ sub _analyze {
 				$type = 'EXTRA';
 			}
 
-			# non-core tests PASS automatically
 			if ( $type eq 'CORE' or $result ) {
 				ok( $result, "[$type] $metric->{'name'}" );
 			} else {
-				pass( "[$type] $metric->{'name'} treated as PASS" );
+				if ( ! $ENV{PERL_APOCALYPSE} ) {
+					# non-core tests PASS automatically for ease of use
+					pass( "[$type] $metric->{'name'} treated as PASS" );
+				} else {
+					fail( "[$type] $metric->{'name'}" );
+				}
 			}
 
 			# print more diag if it failed
 			if ( ! $result && $ENV{TEST_VERBOSE} ) {
 				diag( '[' . $metric->{'name'} . '] error(' . $metric->{'error'} . ') remedy(' . $metric->{'remedy'} . ')' );
 				if ( $metric->{'name'} eq 'prereq_matches_use' or $metric->{'name'} eq 'build_prereq_matches_use' ) {
-					require Data::Dumper;
+					require Data::Dumper; ## no critic (Bangs::ProhibitDebuggingModules)
 					diag( "module information: " . Data::Dumper::Dumper( $analyzer->d->{'uses'} ) );
 				}
 			}
@@ -168,13 +166,13 @@ sub _cleanup_debian_files {
 
 1;
 
-
 __END__
+
 =pod
 
-=for :stopwords Apocalypse kwalitee
+=encoding UTF-8
 
-=encoding utf-8
+=for :stopwords Apocalypse Niebur Ryan kwalitee
 
 =for Pod::Coverage do_test
 
@@ -184,7 +182,7 @@ Test::Apocalypse::Kwalitee - Plugin for Test::Kwalitee
 
 =head1 VERSION
 
-  This document describes v1.002 of Test::Apocalypse::Kwalitee - released April 21, 2011 as part of Test-Apocalypse.
+  This document describes v1.003 of Test::Apocalypse::Kwalitee - released October 24, 2014 as part of Test-Apocalypse.
 
 =head1 DESCRIPTION
 
@@ -208,35 +206,33 @@ Apocalypse <APOCAL@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Apocalypse.
+This software is copyright (c) 2014 by Apocalypse.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
-The full text of the license can be found in the LICENSE file included with this distribution.
+The full text of the license can be found in the
+F<LICENSE> file included with this distribution.
 
 =head1 DISCLAIMER OF WARRANTY
 
-BECAUSE THIS SOFTWARE IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY
-FOR THE SOFTWARE, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT
-WHEN OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER
-PARTIES PROVIDE THE SOFTWARE "AS IS" WITHOUT WARRANTY OF ANY KIND,
-EITHER EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE
-IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
-PURPOSE. THE ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE
-SOFTWARE IS WITH YOU. SHOULD THE SOFTWARE PROVE DEFECTIVE, YOU ASSUME
-THE COST OF ALL NECESSARY SERVICING, REPAIR, OR CORRECTION.
+THERE IS NO WARRANTY FOR THE PROGRAM, TO THE EXTENT PERMITTED BY
+APPLICABLE LAW.  EXCEPT WHEN OTHERWISE STATED IN WRITING THE COPYRIGHT
+HOLDERS AND/OR OTHER PARTIES PROVIDE THE PROGRAM "AS IS" WITHOUT WARRANTY
+OF ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO,
+THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
+PURPOSE.  THE ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE PROGRAM
+IS WITH YOU.  SHOULD THE PROGRAM PROVE DEFECTIVE, YOU ASSUME THE COST OF
+ALL NECESSARY SERVICING, REPAIR OR CORRECTION.
 
 IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING
-WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR
-REDISTRIBUTE THE SOFTWARE AS PERMITTED BY THE ABOVE LICENCE, BE LIABLE
-TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL, OR
-CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE THE
-SOFTWARE (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING
-RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A
-FAILURE OF THE SOFTWARE TO OPERATE WITH ANY OTHER SOFTWARE), EVEN IF
-SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH
-DAMAGES.
+WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MODIFIES AND/OR CONVEYS
+THE PROGRAM AS PERMITTED ABOVE, BE LIABLE TO YOU FOR DAMAGES, INCLUDING ANY
+GENERAL, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE
+USE OR INABILITY TO USE THE PROGRAM (INCLUDING BUT NOT LIMITED TO LOSS OF
+DATA OR DATA BEING RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD
+PARTIES OR A FAILURE OF THE PROGRAM TO OPERATE WITH ANY OTHER PROGRAMS),
+EVEN IF SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF
+SUCH DAMAGES.
 
 =cut
-
